@@ -7,6 +7,7 @@ from decorated.decorators.once import Once, OnceSession
 from decorated.decorators.remove_extra_args import RemoveExtraArgs
 from decorated.decorators.retries import Retries
 from decorated.decorators.synchronized import Synchronized
+from decorated.decorators.timeout import TimeoutDecorator
 
 Function = Function
 partial = partial
@@ -19,3 +20,4 @@ OnceSession = OnceSession
 remove_extra_args = RemoveExtraArgs
 retries = Retries
 synchronized = Synchronized
+timeout = TimeoutDecorator
